#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAJORITY_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAJORITY_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/majority.hpp>

#endif
